[RFC/PATCH v2 06/16] mfd: bcm2835-pm: Rename asb to rpivid_asb

Nicolas Saenz Julienne nsaenzjulienne at suse.de
Tue Feb 9 07:59:02 EST 2021


In anticipation to supporting BCM2711 on which new ASB took over V3D,
use a more explicit name on the currently supported one.

Signed-off-by: Nicolas Saenz Julienne <nsaenzjulienne at suse.de>
---
 drivers/mfd/bcm2835-pm.c        |  8 ++++----
 drivers/soc/bcm/bcm2835-power.c | 10 +++++-----
 include/linux/mfd/bcm2835-pm.h  |  2 +-
 3 files changed, 10 insertions(+), 10 deletions(-)

diff --git a/drivers/soc/bcm/bcm2835-power.c b/drivers/soc/bcm/bcm2835-power.c
index 1e0041ec8132..59b8abfc5617 100644
--- a/drivers/soc/bcm/bcm2835-power.c
+++ b/drivers/soc/bcm/bcm2835-power.c
@@ -126,8 +126,8 @@
 
 #define ASB_AXI_BRDG_ID			0x20
 
-#define ASB_READ(reg) readl(power->asb + (reg))
-#define ASB_WRITE(reg, val) writel(PM_PASSWORD | (val), power->asb + (reg))
+#define ASB_READ(reg) readl(power->rpivid_asb + (reg))
+#define ASB_WRITE(reg, val) writel(PM_PASSWORD | (val), power->rpivid_asb + (reg))
 
 struct bcm2835_power_domain {
 	struct generic_pm_domain base;
@@ -140,8 +140,8 @@ struct bcm2835_power {
 	struct device		*dev;
 	/* PM registers. */
 	void __iomem		*base;
-	/* AXI Async bridge registers. */
-	void __iomem		*asb;
+	/* RPiVid bridge registers. */
+	void __iomem		*rpivid_asb;
 
 	struct genpd_onecell_data pd_xlate;
 	struct bcm2835_power_domain domains[BCM2835_POWER_DOMAIN_COUNT];
@@ -625,7 +625,7 @@ static int bcm2835_power_probe(struct platform_device *pdev)
 
 	power->dev = dev;
 	power->base = pm->base;
-	power->asb = pm->asb;
+	power->rpivid_asb = pm->rpivid_asb;
 
 	id = ASB_READ(ASB_AXI_BRDG_ID);
 	if (id != 0x62726467 /* "BRDG" */) {
diff --git a/include/linux/mfd/bcm2835-pm.h b/include/linux/mfd/bcm2835-pm.h
index ed37dc40e82a..ed4bd548db09 100644
--- a/include/linux/mfd/bcm2835-pm.h
+++ b/include/linux/mfd/bcm2835-pm.h
@@ -8,7 +8,7 @@
 struct bcm2835_pm {
 	struct device *dev;
 	void __iomem *base;
-	void __iomem *asb;
+	void __iomem *rpivid_asb;
 };
 
 #endif /* BCM2835_MFD_PM_H */
diff --git a/drivers/mfd/bcm2835-pm.c b/drivers/mfd/bcm2835-pm.c
index 42fe67f1538e..836343e69f43 100644
--- a/drivers/mfd/bcm2835-pm.c
+++ b/drivers/mfd/bcm2835-pm.c
@@ -50,15 +50,15 @@ static int bcm2835_pm_probe(struct platform_device *pdev)
 	if (ret)
 		return ret;
 
 	/* We'll use the presence of the AXI ASB regs in the
 	 * bcm2835-pm binding as the key for whether we can reference
 	 * the full PM register range and support power domains.
 	 */
 	res = platform_get_resource(pdev, IORESOURCE_MEM, 1);
 	if (res) {
-		pm->asb = devm_ioremap_resource(dev, res);
-		if (IS_ERR(pm->asb))
-			return PTR_ERR(pm->asb);
+		pm->rpivid_asb = devm_ioremap_resource(dev, res);
+		if (IS_ERR(pm->rpivid_asb))
+			return PTR_ERR(pm->rpivid_asb);
 
 		ret = devm_mfd_add_devices(dev, -1,
 					   bcm2835_power_devs,
@@ -50,15 +50,15 @@ static int bcm2835_pm_probe(struct platform_device *pdev)
 		return ret;
 
-	/* We'll use the presence of the AXI ASB regs in the
+	/* We'll use the presence of the RPiVid ASB regs in the
 	 * bcm2835-pm binding as the key for whether we can reference
 	 * the full PM register range and support power domains.
-- 
2.30.0




More information about the linux-arm-kernel mailing list